Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(267)

Unified Diff: chrome/browser/chromeos/drive/fileapi/async_file_util.h

Issue 442383002: Move storage-related files from webkit/ to new top-level directory storage/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/drive/fileapi/async_file_util.h
diff --git a/chrome/browser/chromeos/drive/fileapi/async_file_util.h b/chrome/browser/chromeos/drive/fileapi/async_file_util.h
index 607758b0ffb69864028add5a7b64cffd984e0ddb..20e879d520d13956c62a5d0cd154dc4508b375cf 100644
--- a/chrome/browser/chromeos/drive/fileapi/async_file_util.h
+++ b/chrome/browser/chromeos/drive/fileapi/async_file_util.h
@@ -7,7 +7,7 @@
#include "base/basictypes.h"
#include "base/callback.h"
-#include "webkit/browser/fileapi/async_file_util.h"
+#include "storage/browser/fileapi/async_file_util.h"
namespace drive {
@@ -15,80 +15,78 @@ class FileSystemInterface;
namespace internal {
-// The implementation of fileapi::AsyncFileUtil for Drive File System.
-class AsyncFileUtil : public fileapi::AsyncFileUtil {
+// The implementation of storage::AsyncFileUtil for Drive File System.
+class AsyncFileUtil : public storage::AsyncFileUtil {
public:
AsyncFileUtil();
virtual ~AsyncFileUtil();
- // fileapi::AsyncFileUtil overrides.
+ // storage::AsyncFileUtil overrides.
virtual void CreateOrOpen(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
int file_flags,
const CreateOrOpenCallback& callback) OVERRIDE;
virtual void EnsureFileExists(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const EnsureFileExistsCallback& callback) OVERRIDE;
virtual void CreateDirectory(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
bool exclusive,
bool recursive,
const StatusCallback& callback) OVERRIDE;
virtual void GetFileInfo(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const GetFileInfoCallback& callback) OVERRIDE;
virtual void ReadDirectory(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const ReadDirectoryCallback& callback) OVERRIDE;
- virtual void Touch(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
- const base::Time& last_access_time,
- const base::Time& last_modified_time,
- const StatusCallback& callback) OVERRIDE;
- virtual void Truncate(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
- int64 length,
- const StatusCallback& callback) OVERRIDE;
+ virtual void Touch(scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
+ const base::Time& last_access_time,
+ const base::Time& last_modified_time,
+ const StatusCallback& callback) OVERRIDE;
+ virtual void Truncate(scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
+ int64 length,
+ const StatusCallback& callback) OVERRIDE;
virtual void CopyFileLocal(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& src_url,
- const fileapi::FileSystemURL& dest_url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& src_url,
+ const storage::FileSystemURL& dest_url,
CopyOrMoveOption option,
const CopyFileProgressCallback& progress_callback,
const StatusCallback& callback) OVERRIDE;
virtual void MoveFileLocal(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& src_url,
- const fileapi::FileSystemURL& dest_url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& src_url,
+ const storage::FileSystemURL& dest_url,
CopyOrMoveOption option,
const StatusCallback& callback) OVERRIDE;
virtual void CopyInForeignFile(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
+ scoped_ptr<storage::FileSystemOperationContext> context,
const base::FilePath& src_file_path,
- const fileapi::FileSystemURL& dest_url,
+ const storage::FileSystemURL& dest_url,
const StatusCallback& callback) OVERRIDE;
virtual void DeleteFile(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const StatusCallback& callback) OVERRIDE;
virtual void DeleteDirectory(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const StatusCallback& callback) OVERRIDE;
virtual void DeleteRecursively(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const StatusCallback& callback) OVERRIDE;
virtual void CreateSnapshotFile(
- scoped_ptr<fileapi::FileSystemOperationContext> context,
- const fileapi::FileSystemURL& url,
+ scoped_ptr<storage::FileSystemOperationContext> context,
+ const storage::FileSystemURL& url,
const CreateSnapshotFileCallback& callback) OVERRIDE;
private:
« no previous file with comments | « chrome/browser/chromeos/drive/file_task_executor_unittest.cc ('k') | chrome/browser/chromeos/drive/fileapi/async_file_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698